#!/usr/bin/env python3

import rvcprint

rvcprint.bdmodel('IBVS-holonomic.bd')
